==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRewriteFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class HTTPRewriteFluent<A extends HTTPRewriteFluent<A>> extends BaseFluent<A>{
  public HTTPRewriteFluent() {
  }
  public HTTPRewriteFluent(HTTPRewrite instance) {
    instance = (instance != null ? instance : new HTTPRewrite());

    if (instance != null) {
      this.withAuthority(instance.getAuthority());
      this.withUri(instance.getUri());
      this.withAuthority(instance.getAuthority());
      this.withUri(instance.getUri());
    }
  }
  private String authority;
  private String uri;
  public String getAuthority() {
    return this.authority;
  }
  public A withAuthority(String authority) {
    this.authority=authority; return (A) this;
  }
  public boolean hasAuthority() {
    return this.authority != null;
  }
  public String getUri() {
    return this.uri;
  }
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  public boolean hasUri() {
    return this.uri != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRewriteFluent that = (HTTPRewriteFluent) o;
    if (!java.util.Objects.equals(authority, that.authority)) return false;

    if (!java.util.Objects.equals(uri, that.uri)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authority,  uri,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authority != null) { sb.append("authority:"); sb.append(authority + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1beta1-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/HTTPRewriteFluent.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class HTTPRewriteFluent<A extends HTTPRewriteFluent<A>> extends BaseFluent<A>{
  public HTTPRewriteFluent() {
  }
  
  public HTTPRewriteFluent(HTTPRewrite instance) {
    this.copyInstance(instance);
  }
  private String authority;
  private String uri;
  
  protected void copyInstance(HTTPRewrite instance) {
    instance = (instance != null ? instance : new HTTPRewrite());
  
    if (instance != null) {
        this.withAuthority(instance.getAuthority());
        this.withUri(instance.getUri());
        this.withAuthority(instance.getAuthority());
        this.withUri(instance.getUri());
      }
  }
  
  public String getAuthority() {
    return this.authority;
  }
  
  public A withAuthority(String authority) {
    this.authority=authority; return (A) this;
  }
  
  public boolean hasAuthority() {
    return this.authority != null;
  }
  
  public String getUri() {
    return this.uri;
  }
  
  public A withUri(String uri) {
    this.uri=uri; return (A) this;
  }
  
  public boolean hasUri() {
    return this.uri != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HTTPRewriteFluent that = (HTTPRewriteFluent) o;
    if (!java.util.Objects.equals(authority, that.authority)) return false;
  
    if (!java.util.Objects.equals(uri, that.uri)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(authority,  uri,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (authority != null) { sb.append("authority:"); sb.append(authority + ","); }
    if (uri != null) { sb.append("uri:"); sb.append(uri); }
    sb.append("}");
    return sb.toString();
  }
  

}
